==================
Module *operators*
==================

.. automodule:: findiff.operators
    :members:


.. autoclass:: findiff.operators.FinDiff
    :members:


.. autoclass:: findiff.operators.Coefficient
    :members:


.. autoclass:: findiff.operators.Identity
    :members:



